angular
    .module('zns.services', [])
    .value("znsConfig", {
        baseUrl: "http://znsadmin.herokuapp.com/api"
    })
    .factory('BackgroundPlayer', function($ionicLoading){
        var player,
            playbackStatus,
            currentAudioMedia;

        var playAudio = function(media){
            currentAudioMedia = media;

            var src;

            if (ionic.Platform.isAndroid()) {
                src = media.android;
            } else {
                src = media.ios;
            }

            if (player) player.stop();

            player = new Media(src, function() {
                    $ionicLoading.hide();
                }, function(error){
                    $ionicLoading.hide();

                    switch(error.code){
                    case MediaError.MEDIA_ERR_NONE_ACTIVE:
                        // do nothing
                        break;
                    default:
                        navigator.notification.alert(
                                                    'This station is unavailable.', // message
                                                    null, // callback
                                                    'Playback Error', // title
                                                    'Ok');
                        break;
                    }
                }, function(status) {
                    playbackStatus = status;
                    switch(status){
                    case Media.MEDIA_STARTING:
                        $ionicLoading.show({
                            template: 'Playing...'
                        });
                        break;
                    case Media.MEDIA_RUNNING:
                        $ionicLoading.hide();
                        break;
                    case Media.MEDIA_PAUSED:
                        break;
                    case Media.MEDIA_STOPPED:
                        $ionicLoading.hide();
                        player = null;
                        break;
                    }
                });

            player.play({playAudioWhenScreenIsLocked: true});
        };

        var pauseAudio = function(){
            if (!player) return;

            player.stop();
        }

        var resumeAudio = function(){
            playAudio(currentAudioMedia);
        }

        var playVideo = function(media){
            if (!media) return;

            if (player) player.stop();

            if (ionic.Platform.isAndroid()) {
                window.open(media.android, '_system', 'location=no');
            } else {
                $ionicLoading.show({
                    template: 'Loading Video...'
                });

                window.location = media.ios;

                setTimeout($ionicLoading.hide, 750);
            }
        };

        return {
            playAudio: playAudio,
            pauseAudio: pauseAudio,
            resumeAudio: resumeAudio,
            isPlaying: function(){ return player != null && playbackStatus === Media.MEDIA_RUNNING; },
            isPaused: function(){ return player != null && playbackStatus == Media.MEDIA_PAUSED; },
            playVideo: playVideo
        }
    })
    .factory('Stations', function(znsConfig, $http) {
        var data = [];

        var load = function(){
            var promise = $http.get(znsConfig.baseUrl + "/radio");
            promise.then(function(result){
                    data = result.data;
                }, function(){
                    // Error
                });

            return promise;
        };

        return {
            load: load,
            all: function() {
                return data;
            },
            get: function(id) {
                return data[id];
            }
        }
    })
    .factory('LiveStreams', function(znsConfig, $http) {
        var data = [];

        var load = function(){
            var promise = $http.get(znsConfig.baseUrl + "/tv");

            promise.then(function(result){
                data = result.data;
            }, function(){
                // Error
            })

            return promise;
        };

        return {
            load: load,
            all: function() {
                return data;
            },
            get: function(id) {
                // Simple index lookup
                return data[id];
            }
        }
    })
    .factory('NewsService', function(znsConfig, $http) {
        var data = [];

        var load = function(){
            var promise = $http.get(znsConfig.baseUrl + "/news");
            promise.then(function(result){
                            data = result.data;
                        }, function(){
                            data = null;
                        });
            return promise;
        };

        return {
            load: load,
            all: function() {
                return data;
            },
            get: function(id) {
                // Simple index lookup
                return data[id];
            }
        }
    })
    .factory('MediaService', function(znsConfig, $http) {
        var data = [];

        var load = function(){
            var promise = $http.get(znsConfig.baseUrl + "/media");
            promise.then(function(result){
                data = result.data;
            }, function(){
                data = null;
            });
            return promise;
        };

        return {
            load: load,
            all: function() {
                return data;
            },
            get: function(id) {
                return data[id];
            }
        }
    });